@@ -12,23 +12,29 @@ from .utils import coerce_concise
 
 
 def csvreader(open_csvfile_obj, config_dict):
-    """From open CSV file object, return tuple: (shapes dict, warnings dict)."""
+    """From open CSV file object, return shapes dict."""
     (csvrows, csvwarns) = _get_rows(open_csvfile_obj, config_dict)
     (tapshapes, tapwarns) = _get_tapshapes(csvrows, config_dict)
     tapwarns = {**csvwarns, **tapwarns}
     tapshapes = _add_namespaces(tapshapes, config_dict, csvrows)
-    return (tapshapes, tapwarns)
+    tapshapes = _add_tapwarns(tapshapes, tapwarns)
+    return tapshapes
 
 
 def _add_namespaces(tapshapes=None, config_dict=None, csvrows=None):
-    """@@@"""
+    """Adds key 'namespaces' to tapshapes dict."""
     prefixes_used = _get_prefixes_actually_used(csvrows)
-    tapshapes['namespaces'] = {}
-    if config_dict.get('prefixes'):
+    tapshapes["namespaces"] = {}
+    if config_dict.get("prefixes"):
         for prefix in prefixes_used:
-            if config_dict['prefixes'].get(prefix):
-                tapshapes['namespaces'][prefix] = config_dict['prefixes'].get(prefix)
+            if config_dict["prefixes"].get(prefix):
+                tapshapes["namespaces"][prefix] = config_dict["prefixes"].get(prefix)
+    return tapshapes
 
+
+def _add_tapwarns(tapshapes=None, tapwarns=None):
+    """Adds key 'warnings' to tapshapes dict."""
+    tapshapes["warnings"] = tapwarns
     return tapshapes
 
 
@@ -36,7 +42,7 @@ def _get_prefixes_actually_used(csvrows):
     """@@@"""
     prefixes = set()
     for row in csvrows:
-        for element in ['propertyID', 'valueDataType', 'shapeID', 'valueShape']:
+        for element in ["propertyID", "valueDataType", "shapeID", "valueShape"]:
             if row.get(element):
                 pre = re.match(r"(.*:)", row.get(element))
                 if pre:
@@ -71,14 +77,15 @@ def _get_rows(open_csvfile_obj, config_dict):
         column = coerce_concise(column)
         column = _normalize_element_name(column, config_dict.get("element_aliases"))
         new_header_line_list.append(column)
-    csv_warns = defaultdict(dict)
 
+    csv_warns = defaultdict(dict)
     for column in new_header_line_list:
         if column.lower() not in recognized_elements:
             warn = f"Non-DCTAP element {repr(column)} not configured as extra element."
             csv_warns["csv"] = {}
             csv_warns["csv"]["column"] = []
             csv_warns["csv"]["column"].append(warn)
+
     new_header_line_str = ",".join(new_header_line_list)
     csvlines_stripped[0] = new_header_line_str
     if "propertyID" not in csvlines_stripped[0]:
@@ -102,9 +109,8 @@ def _get_tapshapes(rows, config_dict):
 
     (main_stems, xtra_stems) = get_stems(TAPStatementTemplate, config_dict)
 
-    # fmt: off
-    shapes = {}                             # Dict for shapeID-to-TAPShape_list.
-    warns = defaultdict(dict)               # Dict for shapeID-to-warnings_list.
+    shapes = {}  # dict for shapeID-to-TAPShape_list
+    warns = defaultdict(dict)  # dict for shapeID-to-warnings_list
 
     for row in rows:
         sh_id = ""
@@ -162,15 +168,12 @@ def _get_tapshapes(rows, config_dict):
 
         for sh_obj in list(shapes.values()):
             sh_dict = asdict(sh_obj)
-            sh_dict[
-                "statement_templates"
-            ] = sh_dict.pop("state_list")
+            sh_dict["statement_templates"] = sh_dict.pop("state_list")
             list_of_shapes.append(sh_dict)
 
         shapes_dict = _simplify(shapes_dict)
 
     return (shapes_dict, warns_dict)
-    # fmt: on
 
 
 def _mkshape(row_dict=None, config_dict=None):
@@ -184,7 +187,13 @@ def _mkshape(row_dict=None, config_dict=None):
 
     Returns:
         Unpopulated instance of dctap.tapclasses.TAPShape, by default:
-        - TAPShape(shapeID='', shapeLabel='', state_list=[], shape_warns={}, state_extras={})
+        - TAPShape(
+              shapeID='',
+              shapeLabel='',
+              state_list=[],
+              shape_warns={},
+              state_extras={}
+          )
         - Plus extra TAPShape fields as per config settings.
     """
     (main_shems, xtra_shems) = get_shems(shape_class=TAPShape, settings=config_dict)
