@@ -48,7 +48,7 @@ def pprint_tapshapes(tapshapes_dict, config_dict):
 
 
 def print_warnings(warnings_dict):
-    """@@@"""
+    """Print warnings to stdout."""
     # pylint: disable=logging-fstring-interpolation
     print("", file=sys.stderr)
     echo = stderr_logger()
