@@ -9,26 +9,11 @@ from dctap.defaults import DEFAULT_CONFIGFILE_NAME
 NONDEFAULT_CONFIG_YAML = """\
 default_shape_identifier: "default"
 
-### Commentary that would be stripped from "terse" config file.
-# list_elements:
-# - propertyID
-
 prefixes:
     ":": "http://example.org/"
     "dcterms:": "http://purl.org/dc/terms/"
 """
 
-def test_terse_configfile(tmp_path):
-    """Write config file without verbose commentary."""
-    os.chdir(tmp_path)
-    write_configfile(
-        configfile_name=DEFAULT_CONFIGFILE_NAME, 
-        config_yamldoc=NONDEFAULT_CONFIG_YAML,
-        terse=True,
-    )
-    assert "Commentary" not in open(DEFAULT_CONFIGFILE_NAME).read()
-    assert "list_elements" in open(DEFAULT_CONFIGFILE_NAME).read()
-
 def test_write_default_configfile_and_read_back(tmp_path):
     """Write DEFAULT_CONFIG_YAML to DEFAULT_CONFIGFILE_NAME and read back as text."""
     os.chdir(tmp_path)
